@@ -75,24 +75,6 @@ module_report_server <- function(input,
       )
       rv$aggregated_exported <- TRUE
     }
-
-    if (is.null(rv$affectedids_exported)) {
-      # export descriptive results (inkl. atemporal plausbility)
-      DQAstats::export_affected_ids(
-        output_dir = tempdir(),
-        rv = rv,
-        object = rv$conformance$value_conformance
-      )
-
-      # export uniqueness results
-      DQAstats::export_affected_ids(
-        output_dir = tempdir(),
-        rv = rv,
-        object = rv$results_plausibility_unique
-      )
-      rv$affectedids_exported <- TRUE
-    }
-
     waiter::waiter_hide()
   })
 
@@ -154,38 +136,6 @@ module_report_server <- function(input,
     },
     contentType = "application/zip"
   )
-
-  output$download_affected <- downloadHandler(
-    filename = function() {
-      paste0("DQA_conspicuous_IDs_",
-             gsub("\\-|\\:| ",
-                  "",
-                  substr(rv$start_time, 1, 16)),
-             "_",
-             rv$sitename,
-             ".zip")
-    },
-    content = function(fname) {
-
-      # temporarily set tempdir as wd
-      oldwd <- getwd()
-      setwd(tempdir())
-
-      exportdir <- paste0(tempdir(), "/conspicuous_ids/")
-
-      # export files
-      utils::zip(
-        zipfile = fname,
-        files = c(
-          paste0("conspicuous_ids/",
-                 list.files(exportdir))
-        ))
-
-      # return to old wd
-      setwd(oldwd)
-    },
-    contentType = "application/zip"
-  )
 }
 
 #' @title module_report_ui
@@ -243,18 +193,6 @@ module_report_ui <- function(id) {
               "padding: 9.5px 9.5px 9.5px 9.5px; ",
               "margin: 6px 10px 6px 10px;")),
           width = 12
-        ),
-        box(
-          title = "Conspicuous IDs",
-          downloadButton(
-            ns("download_affected"),
-            "Download IDs (ZIP)",
-            style = paste0(
-              "white-space: normal; ",
-              "text-align:center; ",
-              "padding: 9.5px 9.5px 9.5px 9.5px; ",
-              "margin: 6px 10px 6px 10px;")),
-          width = 12
         )
       )
     )
